import {
  select,
  csv,
  scaleLinear,
  extent,
  axisLeft,
  axisBottom,
  format
} from 'd3';

const svg = select('svg');

const width = +svg.attr('width');
const height = +svg.attr('height');

const render = data => {
  const title = 'Graduate students labor force info';
  
  const xValue = d => d.Grad_total;
  const xAxisLabel = 'Total Graduates';
  
  const yValue = d => d.Grad_employed;
  const yAxisLabel = 'Employed';
  
  const circleRadius = 4;
  
  const margin = { top: 70, right: 40, bottom: 88, left: 120 };
  const innerWidth = width - margin.left - margin.right;
  const innerHeight = height - margin.top - margin.bottom;
  
  const xScale = scaleLinear()
    .domain(extent(data, xValue))
    .range([0, innerWidth])
    .nice();
  
  const yScale = scaleLinear()
    .domain(extent(data, yValue))
    .range([innerHeight, 0])
    .nice();
  
  const g = svg.append('g')
    .attr('transform', `translate(${margin.left},${margin.top})`);
  
  const AxisTickFormat = number => 
  	format('.2s')(number);
  
  const xAxis = axisBottom(xScale)
    .tickFormat(AxisTickFormat)
    .tickSize(-innerHeight)
    .tickPadding(15);
  
  const yAxis = axisLeft(yScale)
    .tickFormat(AxisTickFormat)
    .tickSize(-innerWidth)
    .tickPadding(5);
  
  const yAxisG = g.append('g').call(yAxis);
  yAxisG.selectAll('.domain').remove();
  
  yAxisG.append('text')
      .attr('class', 'axis-label')
      .attr('y', -75)
      .attr('x', -innerHeight / 2)
      .attr('fill', 'black')
      .attr('transform', `rotate(-90)`)
      .attr('text-anchor', 'middle')
      .text(yAxisLabel);
  
  const xAxisG = g.append('g').call(xAxis)
    .attr('transform', `translate(0,${innerHeight})`);
  
  xAxisG.select('.domain').remove();
  
  xAxisG.append('text')
      .attr('class', 'axis-label')
      .attr('y', 75)
      .attr('x', innerWidth / 2)
      .attr('fill', 'black')
      .text(xAxisLabel);
  
  g.selectAll('circle').data(data)
    .enter().append('circle')
      .attr('cy', d => yScale(yValue(d)))
      .attr('cx', d => xScale(xValue(d)))
      .attr('r', circleRadius);
  
  g.append('text')
      .attr('class', 'title')
      .attr('y', -15)
      .attr('x', 0)
      .text(title);
};

csv('https://vizhub.com/ilovemanu/datasets/gradudate_students.csv')
  .then(data => {
    data.forEach(d => {
      d.Grad_employed = +d.Grad_employed;
      d.Grad_total = +d.Grad_total;
    });
    render(data);
  });